@@ -1,4 +1,4 @@
-from great_assertions.great_assertions import GreatAssertions
+from great_assertions import GreatAssertions
 import pandas as pd
 import pytest
 
@@ -10,6 +10,11 @@ class GreatAssertionPandasTests(GreatAssertions):
 
         assert "Not a valid pandas/pyspark DataFrame" == str(excinfo.value)
 
+        with pytest.raises(AssertionError) as excinfo:
+            self.assertExpectColumnValuesToBeInSet(1, "col_1", set(("Apple")))
+
+        assert "Not a valid pandas/pyspark DataFrame" == str(excinfo.value)
+
     def test_pandas_expect_table_row_count_to_equal(self):
         df = pd.DataFrame({"col_1": [100, 200, 300], "col_2": [10, 20, 30]})
         self.assertExpectTableRowCountToEqual(df, 3)
@@ -35,7 +40,7 @@ class GreatAssertionPandasTests(GreatAssertions):
         df = pd.DataFrame({"col_1": [100.02, 200.01, 300.01], "col_2": [10, 20, 30]})
         self.assertExpectColumnValuesToBeBetween(df, "col_1", 100.01, 300.02)
 
-        # Same float
+        # Equality float
         df = pd.DataFrame({"col_1": [100.05, 200.01, 300.05], "col_2": [10, 20, 30]})
         self.assertExpectColumnValuesToBeBetween(df, "col_1", 100.05, 300.05)
 
@@ -198,10 +203,10 @@ class GreatAssertionPandasTests(GreatAssertions):
     def test_assert_pandas_expect_table_columns_to_match_set(self):
         df = pd.DataFrame({"col_1": [100], "col_2": ["a"], "col_3": [1.01]})
         self.assertExpectTableColumnsToMatchSet(df, set(("col_1", "col_2", "col_3")))
-        # self.assertExpectTableColumnsToMatchSet(df, set(("col_2", "col_1", "col_3")))
-        # self.assertExpectTableColumnsToMatchSet(df, list(("col_1", "col_2", "col_3")))
-        # self.assertExpectTableColumnsToMatchSet(df, list(("col_2", "col_1", "col_3")))
-        # self.expect_table_columns_to_match_set(df, list(("col_2", "col_1", "col_3")))
+        self.assertExpectTableColumnsToMatchSet(df, set(("col_2", "col_1", "col_3")))
+        self.assertExpectTableColumnsToMatchSet(df, list(("col_1", "col_2", "col_3")))
+        self.assertExpectTableColumnsToMatchSet(df, list(("col_2", "col_1", "col_3")))
+        self.expect_table_columns_to_match_set(df, list(("col_2", "col_1", "col_3")))
 
     def test_assert_pandas_expect_table_columns_to_match_set_fail(self):
         df = pd.DataFrame({"col_1": [100], "col_2": ["a"], "col_3": [1.01]})
@@ -234,7 +239,7 @@ class GreatAssertionPandasTests(GreatAssertions):
         df = pd.DataFrame({"col_1": ["2019/05/13", "2018/12/12", "2015/10/01"]})
 
         self.assertExpectDateRangeToBeLessThan(
-            df, "col_1", "2019/05/14", format="%Y/%m/%d"
+            df, "col_1", "2019/05/14", date_format="%Y/%m/%d"
         )
 
     def test_assert_expect_date_range_to_be_less_than_fail(self):
