@@ -1,4 +1,4 @@
-from great_assertions.great_assertions import GreatAssertions
+from great_assertions import GreatAssertions
 from pyspark.sql import SparkSession
 import pytest
 
@@ -109,6 +109,10 @@ class GreatAssertionPySparkTests(GreatAssertions):
         )
 
     def test_pyspark_assert_expect_column_values_to_match_regex_fail(self):
+        import sys
+
+        print(sys.executable)
+
         df = self.spark.createDataFrame(
             [{"col_1": "BA2"}, {"col_1": "BA151"}, {"col_1": "AAA13"}]
         )
@@ -267,7 +271,7 @@ class GreatAssertionPySparkTests(GreatAssertions):
             ]
         )
         self.assertExpectDateRangeToBeLessThan(
-            df, "col_1", "2019/05/14", format="%Y/%m/%d"
+            df, "col_1", "2019/05/14", date_format="%Y/%m/%d"
         )
 
     def test_assert_expect_date_range_to_be_less_than_default(self):
